@@ -7,15 +7,42 @@ use crate::operators::{
     binary_operator::BinaryOperator, mask::VectorMask, options::OperatorOptions,
 };
 
-use crate::sparse_matrix::SparseMatrix;
-use crate::sparse_vector::SparseVector;
+use crate::value_types::sparse_matrix::SparseMatrix;
+use crate::value_types::sparse_vector::SparseVector;
 
-use crate::value_type::{AsBoolean, ValueType};
+use crate::value_types::value_type::{AsBoolean, ValueType};
 
 use crate::bindings_to_graphblas_implementation::{
     GrB_BinaryOp, GrB_Descriptor, GrB_Matrix_reduce_BinaryOp,
 };
 
+// Implemented methods do not provide mutable access to GraphBLAS operators or options.
+// Code review must consider that no mtable access is provided.
+// https://doc.rust-lang.org/nomicon/send-and-sync.html
+unsafe impl Send for BinaryOperatorReducer<bool> {}
+unsafe impl Send for BinaryOperatorReducer<u8> {}
+unsafe impl Send for BinaryOperatorReducer<u16> {}
+unsafe impl Send for BinaryOperatorReducer<u32> {}
+unsafe impl Send for BinaryOperatorReducer<u64> {}
+unsafe impl Send for BinaryOperatorReducer<i8> {}
+unsafe impl Send for BinaryOperatorReducer<i16> {}
+unsafe impl Send for BinaryOperatorReducer<i32> {}
+unsafe impl Send for BinaryOperatorReducer<i64> {}
+unsafe impl Send for BinaryOperatorReducer<f32> {}
+unsafe impl Send for BinaryOperatorReducer<f64> {}
+
+unsafe impl Sync for BinaryOperatorReducer<bool> {}
+unsafe impl Sync for BinaryOperatorReducer<u8> {}
+unsafe impl Sync for BinaryOperatorReducer<u16> {}
+unsafe impl Sync for BinaryOperatorReducer<u32> {}
+unsafe impl Sync for BinaryOperatorReducer<u64> {}
+unsafe impl Sync for BinaryOperatorReducer<i8> {}
+unsafe impl Sync for BinaryOperatorReducer<i16> {}
+unsafe impl Sync for BinaryOperatorReducer<i32> {}
+unsafe impl Sync for BinaryOperatorReducer<i64> {}
+unsafe impl Sync for BinaryOperatorReducer<f32> {}
+unsafe impl Sync for BinaryOperatorReducer<f64> {}
+
 #[derive(Debug, Clone)]
 pub struct BinaryOperatorReducer<T: ValueType> {
     _value: PhantomData<T>,
@@ -97,8 +124,10 @@ mod tests {
     use crate::context::{Context, Mode};
     use crate::operators::binary_operator::{First, Plus};
 
-    use crate::sparse_matrix::{FromMatrixElementList, MatrixElementList, Size};
-    use crate::sparse_vector::{FromVectorElementList, GetVectorElementValue, VectorElementList};
+    use crate::value_types::sparse_matrix::{FromMatrixElementList, MatrixElementList, Size};
+    use crate::value_types::sparse_vector::{
+        FromVectorElementList, GetVectorElementValue, VectorElementList,
+    };
 
     #[test]
     fn test_binary_operator_reducer() {
